@@ -6,12 +6,22 @@ use warnings;
 use DBI;
 use File::Spec;
 
+sub _file {
+    return File::Spec->catfile(File::Spec->tmpdir, 'test.db');
+}
+
+sub dbi {
+    return "dbi:SQLite:" . _file();
+}
+
 sub dbh {
-    my $table = File::Spec->catfile(File::Spec->tmpdir, 'test.db');
+    my $class = shift;
+
+    my $table = _file;
 
     my $exists = -f $table;
 
-    my $dbh = DBI->connect("dbi:SQLite:$table") or die $DBI::errstr;
+    my $dbh = DBI->connect($class->dbi) or die $DBI::errstr;
 
     unless ($exists) {
         my $sth = $dbh->prepare(<<"");
